@@ -23,13 +23,7 @@
 #include <gnome.h>
 #include <gpilotd/gnome-pilot-client.h>
 
-#ifdef USING_OAF
-#include <bonobo.h>
-#include <liboaf/liboaf.h>
-#else
 #include <libgnorba/gnorba.h>
-#endif
-
 
 GnomePilotClient *gpc;
 CORBA_Environment ev;
@@ -103,16 +97,10 @@ main (int argc, char *argv[])
 		exit (1);
 	}
 
-#       if USING_OAF
-	gnome_init_with_popt_table ("gpilotd-install-file", "1.0",
-				    argc, argv, options, 0, &pctx);
-#       else /* USING_OAF */
 	gnome_CORBA_init_with_popt_table ("gpilotd-install-file","1.0",
 					 &argc, argv,
 					 options,0,&pctx,
 					 0,&ev);
-#       endif /* USING_OAF */
-
 	
 	gpc = GNOME_PILOT_CLIENT (gnome_pilot_client_new ());
 	gtk_signal_connect (GTK_OBJECT (gpc),"completed_request", (GtkSignalFunc)gpilotd_request_completed, NULL);
@@ -231,11 +219,7 @@ main (int argc, char *argv[])
 
 	/* gpilotd_shutdown (); */
 
-#if USING_OAF
-	bonobo_object_unref (BONOBO_OBJECT (gpc));
-#else /* USING_OAF */
 	CORBA_ORB_shutdown (gnome_CORBA_ORB (), CORBA_FALSE, &ev);
-#endif /* USING_OAF */
 
 	return 0;
 }
