@@ -5,14 +5,7 @@
  */
 #include <config.h>
 
-#ifdef USING_OAF
-/* (For the OAF popt stuff, which otherwise does not get in.)  */
-#include <gnome.h>
-
-#include <liboaf/liboaf.h>
-#else
 #include <libgnorba/gnorba.h>
-#endif
 
 #include <gpilotd/gnome-pilot-client.h>
 
@@ -349,9 +342,6 @@ get_system_info ()
 
 int
 main (int argc, char *argv[]) {
-#ifndef USING_OAF
-	CORBA_Environment ev;
-#endif
         poptContext pctx;
 	
 	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
@@ -362,15 +352,10 @@ main (int argc, char *argv[]) {
 		exit (1);
 	}
 
-#if USING_OAF
-	gnome_init_with_popt_table ("gpilotd-client","1.0",
-				    argc, argv, options, 0, &pctx);
-#else /* USING_OAF */
 	gnome_CORBA_init_with_popt_table ("gpilotd-client","1.0",
 					 &argc,argv,
 					 options,0,&pctx,
 					 0,&ev);
-#endif /* USING_OAF */
 
 	g_message (_("\nBEWARE!!\nThis is a tool for certain parts of the gnome-pilot package.\nUnless you know what you're doing, don't use this tool."));
 
